import sys
import struct
from collections import namedtuple

MapHeader = namedtuple('MapHeader', 'width, height, surface')

def get_map_header(mapfile):
    return MapHeader(*struct.unpack('<hhh', mapfile.read(6)))

def get_contents(file):
    with open(file) as f:
        return f.read()

def load_resources(file):
    contents = get_contents(file)
    return map(lambda s: map(int, s.split(',')), contents.splitlines())
    
def get_index(width, x, y):
    return (x >> 1) + y * width

def main(mapfile, resourcefile):
    resources = load_resources(resourcefile)
    with open(mapfile, 'r+b') as f:
        header = get_map_header(f)
        f.seek(8)
        print "Changing map seed to -1"
        f.write('\xff\xff')
        f.seek(98 + 6 * header.surface)
        resource_data = [0] * header.surface
        for x, y, res in resources:
            resource_data[get_index(header.width >> 1, x, y)] = res
        print "Writing {0} bytes to {1}".format(len(resource_data), mapfile)
        f.write(''.join(map(chr, resource_data)))
    print "Done!".format(len(resource_data), mapfile)

def usage():
    print "Usage\r\n\tpython {0} <map file> <resource file>".format(__file__)

if __name__ == '__main__':
    if len(sys.argv) == 3:
        main(*sys.argv[1:])
    else:
        usage()
